ALF pipeline orchestrating all Hindsight memory operations (retain, recall, reflect). It centralizes caching, circuit breaker gating, retries, and async buffering to match the architecture requirements of llm_core.
Summary
Functions
@spec components() :: [map()]
@spec flow(map(), list(), Keyword.t()) :: Enumerable.t()
@spec start() :: :ok
@spec start(list()) :: :ok
@spec started?() :: true | false
@spec stream(Enumerable.t(), Keyword.t()) :: Enumerable.t()